@@ -12,6 +12,7 @@ from functools import cmp_to_key
 import json
 from copy import deepcopy
 
+from django.conf import settings
 from django.contrib import admin, messages
 from django.contrib.auth import get_permission_codename
 from django.contrib.staticfiles.storage import staticfiles_storage
@@ -49,20 +50,36 @@ class PageAdmin(PageBaseAdmin):
 
     """Admin settings for Page models."""
 
-    fieldsets = (
+    new_fieldsets = [
         (None, {
-            "fields": ("title", "url_title", "parent"),
-        },),
+            "fields": ("title", "slug", "parent"),
+        }),
+        ("Security", {
+            "fields": ("requires_authentication",),
+        }),
         ("Publication", {
-            "fields": ("publication_date", "expiry_date", "is_online",),
-            "classes": ("collapse",),
+            "fields": ("publication_date", "expiry_date", "is_online"),
+            "classes": ("collapse",)
         }),
         ("Navigation", {
-            "fields": ("short_title", "in_navigation",),
-            "classes": ("collapse",),
-        }),
-        PageBaseAdmin.SEO_FIELDS,
-    )
+            "fields": ("short_title", "in_navigation", "hide_from_anonymous"),
+            "classes": ("collapse",)
+        })
+    ]
+
+    new_fieldsets.extend(PageBaseAdmin.fieldsets)
+
+    removed_fieldsets = [
+        new_fieldsets.index(PageBaseAdmin.TITLE_FIELDS),
+        new_fieldsets.index(PageBaseAdmin.PUBLICATION_FIELDS),
+        new_fieldsets.index(PageBaseAdmin.NAVIGATION_FIELDS)
+    ]
+
+    fieldsets = []
+
+    for k, v in enumerate(new_fieldsets):
+        if k not in removed_fieldsets:
+            fieldsets.append(v)
 
     search_adapter_cls = PageSearchAdapter
 
@@ -169,12 +186,12 @@ class PageAdmin(PageBaseAdmin):
         content_fields = [field.name for field in content_cls._meta.fields + content_cls._meta.many_to_many if field.name != "page"]
         fieldsets = super(PageAdmin, self).get_fieldsets(request, obj)
         if content_fields:
-            content_fieldsets = content_cls.fieldsets or (
+            content_fieldsets = content_cls.fieldsets or [
                 ("Page content", {
                     "fields": content_fields,
                 }),
-            )
-            fieldsets = tuple(fieldsets[0:1]) + content_fieldsets + tuple(fieldsets[1:])
+            ]
+            fieldsets = list(fieldsets[0:1]) + content_fieldsets + list(fieldsets[1:])
         return fieldsets
 
     def get_all_children(self, page):
@@ -228,12 +245,12 @@ class PageAdmin(PageBaseAdmin):
         defaults = {"form": ContentForm}
         defaults.update(kwargs)
 
-        if obj and obj.is_content_object == True:
+        if obj and obj.is_content_object:
             self.prepopulated_fields = {}
             self.fieldsets[0][1]['fields'] = ('title',)
         else:
-            self.prepopulated_fields = {"url_title": ("title",), }
-            self.fieldsets[0][1]['fields'] = ("title", "url_title", "parent")
+            self.prepopulated_fields = {"slug": ("title",), }
+            self.fieldsets[0][1]['fields'] = ("title", "slug", "parent")
 
         PageForm = super(PageAdmin, self).get_form(request, obj, **defaults)
 
@@ -250,7 +267,7 @@ class PageAdmin(PageBaseAdmin):
             parent_choices = []
             for page in [homepage] + self.get_all_children(homepage):
                 if page.id not in invalid_parents:
-                    parent_choices.append((page.id, " \u203a ".join(str(breadcrumb) for breadcrumb in self.get_breadcrumbs(page))))
+                    parent_choices.append((page.id, " \u203a ".join(u"{}".format(breadcrumb.title) for breadcrumb in self.get_breadcrumbs(page))))
         else:
             parent_choices = []
 
@@ -377,6 +394,10 @@ class PageAdmin(PageBaseAdmin):
                 Q(owner=page.owner, is_content_object=True)
             ).order_by('-country_group')
 
+        extra_context['display_language_options'] = False
+        if 'cms.middleware.LocalisationMiddleware' in settings.MIDDLEWARE_CLASSES:
+            extra_context['display_language_options'] = True
+
         # Call the change view.
         return super(PageAdmin, self).change_view(request, object_id, extra_context=extra_context, *args, **kwargs)
 
@@ -497,26 +518,40 @@ class PageAdmin(PageBaseAdmin):
         # Check that the user has permission to move pages.
         if not self.has_change_permission(request):
             return HttpResponseForbidden("You do not have permission to move this page.")
+
         # Lock entire table.
-        existing_pages_list = Page.objects.all().select_for_update().values("id", "parent_id", "left", "right", "title").order_by("left")
+        existing_pages_list = Page.objects.all().exclude(
+            is_content_object=True,
+        ).select_for_update().values(
+            "id",
+            "parent_id",
+            "left",
+            "right",
+            "title"
+        ).order_by("left")
         existing_pages = dict(
             (page["id"], page)
             for page
             in existing_pages_list
         )
+
         # Get the page.
         page = existing_pages[int(request.POST["page"])]
         parent_id = page["parent_id"]
+
         # Get all the siblings.
         siblings = [s for s in existing_pages_list if s["parent_id"] == parent_id]
+
         # Find the page to swap.
         direction = request.POST["direction"]
+
         if direction == "up":
             siblings.reverse()
         elif direction == "down":
             pass
         else:
             raise ValueError("Direction should be 'up' or 'down'.")
+
         sibling_iter = iter(siblings)
         for sibling in sibling_iter:
             if sibling["id"] == page["id"]:
@@ -525,25 +560,48 @@ class PageAdmin(PageBaseAdmin):
             other_page = next(sibling_iter)
         except StopIteration:
             return HttpResponse("Page could not be moved, as nothing to swap with.")
+
         # Put the pages in order.
         first_page, second_page = sorted((page, other_page), key=lambda p: p["left"])
+
         # Excise the first page.
         Page.objects.filter(left__gte=first_page["left"], right__lte=first_page["right"]).update(
             left=F("left") * -1,
             right=F("right") * -1,
         )
+
         # Move the other page.
         branch_width = first_page["right"] - first_page["left"] + 1
         Page.objects.filter(left__gte=second_page["left"], right__lte=second_page["right"]).update(
             left=F("left") - branch_width,
             right=F("right") - branch_width,
         )
+
         # Put the page back in.
         second_branch_width = second_page["right"] - second_page["left"] + 1
         Page.objects.filter(left__lte=-first_page["left"], right__gte=-first_page["right"]).update(
             left=(F("left") - second_branch_width) * -1,
-            right = (F("right") - second_branch_width) * -1,
+            right=(F("right") - second_branch_width) * -1,
         )
+
+        # Update all content models to match the left and right of their parents.
+        existing_pages_list = Page.objects.all().exclude(
+            is_content_object=False,
+        ).select_for_update().values(
+            "id",
+            "parent_id",
+            "owner",
+            "left",
+            "right",
+            "title"
+        ).order_by("left")
+
+        for child_page in existing_pages_list:
+            child_page.update(
+                left=F('owner__left'),
+                right=F('owner__right'),
+            )
+
         # Report back.
         return HttpResponse("Page #%s was moved %s." % (page["id"], direction))
 
@@ -567,6 +625,26 @@ class PageAdmin(PageBaseAdmin):
                 content.page = page
                 content.save()
 
+                # for field in original_page._meta.get_fields_with_model():
+                #
+                #     if RelatedField in inspect.getmro(field[0].__class__):
+                #         print field
+                #
+                # for attr in dir(original_page):
+                #     if attr.endswith('_set'):
+                #         print attr
+
+                # links = [rel.get_accessor_name() for rel in original_page._meta.get_all_related_objects()]
+
+                for link in dir(original_page):
+                    if link.endswith('_set') and getattr(original_page, link).__class__.__name__ == "RelatedManager" and link not in ['child_set', 'owner_set', 'link_to_page']:
+                        objects = getattr(original_page, link).all()
+                        for page_object in objects:
+                            new_object = deepcopy(page_object)
+                            new_object.pk = None
+                            new_object.page = page
+                            new_object.save()
+
             return redirect('/admin/pages/page/{}'.format(page.pk))
 
         country_groups = CountryGroup.objects.all()
@@ -587,8 +665,14 @@ class CountryGroupAdmin(admin.ModelAdmin):
     pass
 
 
+class CountryAdmin(admin.ModelAdmin):
+    list_display = ('name', 'group')
+
+
 admin.site.register(Page, PageAdmin)
-admin.site.register(Country)
-admin.site.register(CountryGroup, CountryGroupAdmin)
+
+if 'cms.middleware.LocalisationMiddleware' in settings.MIDDLEWARE_CLASSES:
+    admin.site.register(Country, CountryAdmin)
+    admin.site.register(CountryGroup, CountryGroupAdmin)
 
 page_admin = admin.site._registry[Page]
