@@ -1,5 +1,4 @@
 """Custom middleware used by the pages application."""
-import os
 
 import sys
 
@@ -12,18 +11,7 @@ from django.shortcuts import redirect
 from django.utils.functional import cached_property
 from django.template.response import SimpleTemplateResponse
 
-from cms.apps.pages.models import Page, Country
-
-from django.contrib.gis.geoip import GeoIP
-
-
-def get_client_ip(request):
-    x_forwarded_for = request.META.get('HTTP_X_FORWARDED_FOR')
-    if x_forwarded_for:
-        ip = x_forwarded_for.split(',')[0]
-    else:
-        ip = request.META.get('REMOTE_ADDR')
-    return ip
+from cms.apps.pages.models import Page
 
 
 class RequestPageManager(object):
@@ -36,45 +24,16 @@ class RequestPageManager(object):
         self._path = self._request.path
         self._path_info = self._request.path_info
 
-    def request_geo(self):
-        # Get geoip data path
-        geo_ip_path = os.path.abspath(
-            os.path.join(os.path.split(__file__)[0], 'data'))
-
-        # Country data from geoip
-        g = GeoIP(path=geo_ip_path)
-        return g.country(get_client_ip(self._request))
-
-    def request_country(self):
-
-        country_data = self.request_geo()
-
-        # No code, return None
-        if country_data['country_code'] is None:
-            return None
-
-        # Get country matching code
-        try:
-            country = Country.objects.get(code=country_data['country_code'])
-            if not country:
-                return None
-            else:
-                return country
-        except:
-            return None
-
     @cached_property
     def country(self):
-        return dict(
-            actual=self.request_geo(),
-            cms=self.request_country()
-        )
+        if hasattr(self._request, 'country'):
+            return self._request.country
+        return None
 
     def request_country_group(self):
-        country = self.request_country()
-
-        if country and country.group:
-            return country.group
+        if hasattr(self._request, 'country'):
+            if self._request.country:
+                return self._request.country.group
 
         return None
 
@@ -82,9 +41,11 @@ class RequestPageManager(object):
 
         try:
             # See if the page has any alternate versions for the current country
-            alternate_version = Page.objects.get(is_content_object=True,
-                                                 owner=page,
-                                                 country_group=self.request_country_group())
+            alternate_version = Page.objects.get(
+                is_content_object=True,
+                owner=page,
+                country_group=self.request_country_group()
+            )
 
             return alternate_version
 
@@ -116,7 +77,7 @@ class RequestPageManager(object):
             if slugs:
                 slug = slugs.pop()
                 for child in page.children:
-                    if child.url_title == slug:
+                    if child.slug == slug:
                         do_breadcrumbs(child)
                         break
         if self.homepage:
@@ -174,6 +135,17 @@ class PageMiddleware(object):
             return response
         script_name = page.get_absolute_url()[:-1]
         path_info = request.path[len(script_name):]
+
+        # Continue for media
+        if request.path.startswith('/media/'):
+            return response
+
+        if hasattr(request, 'country') and request.country is not None:
+            script_name = '/{}{}'.format(
+                request.country.code.lower(),
+                script_name
+            )
+
         # Dispatch to the content.
         try:
             try:
@@ -182,6 +154,7 @@ class PageMiddleware(object):
                 # First of all see if adding a slash will help matters.
                 if settings.APPEND_SLASH:
                     new_path_info = path_info + "/"
+
                     try:
                         urlresolvers.resolve(new_path_info, page.content.urlconf)
                     except urlresolvers.Resolver404:
@@ -195,8 +168,17 @@ class PageMiddleware(object):
                 raise ValueError("The view {0!r} didn't return an HttpResponse object.".format(
                     callback.__name__
                 ))
+
+            if request:
+                if page.auth_required() and not request.user.is_authenticated():
+                    return redirect("{}?next={}".format(
+                        settings.LOGIN_URL,
+                        request.path
+                    ))
+
             if isinstance(response, SimpleTemplateResponse):
                 return response.render()
+
             return response
         except Http404 as ex:
             if settings.DEBUG:
