@@ -2,10 +2,11 @@
 from __future__ import unicode_literals
 
 from django import template
+from django.conf import settings
 from django.utils.html import escape
 
 from cms.apps.pages.models import Page
-
+from cms.models import SearchMetaBase
 
 register = template.Library()
 
@@ -26,24 +27,34 @@ def navigation(context, pages, section=None):
     # Compile the entries.
 
     def page_entry(page):
+        # Do nothing if the page is to be hidden from not logged in users
+        if page.hide_from_anonymous and not request.user.is_authenticated():
+            return
+
         url = page.get_absolute_url()
+
         return {
             "url": url,
             "page": page,
             "title": str(page),
-            "here": request.path.startswith(url),
+            "here": request.path.startswith(url)
         }
-    entries = map(page_entry, pages)
+
+    # All the applicable nav items
+    entries = [page_entry(x) for x in pages if page_entry(x) is not None]
+
     # Add the section.
     if section:
         section_entry = page_entry(section)
         section_entry["here"] = context["pages"].current == section_entry["page"]
         entries = [section_entry] + list(entries)
+
     # Render the template.
     context.update({
         "request": request,
         "navigation": entries,
     })
+
     return context
 
 
@@ -54,7 +65,6 @@ def get_navigation(context, pages, section=None):
 
 
 # Page linking.
-
 @register.simple_tag
 def page_url(page, view_func=None, *args, **kwargs):
     """Renders the URL of the given view func in the given page."""
@@ -105,38 +115,10 @@ def meta_description(context, description=None):
         page = request.pages.current
         if page:
             description = page.meta_description
+
     return escape(description or "")
 
 
-@register.simple_tag(takes_context=True)
-def meta_keywords(context, keywords=None):
-    """
-    Renders the content of the meta keywords tag for the current page::
-
-        {% meta_keywords %}
-
-    You can override the meta keywords by setting a context variable called
-    'meta_keywords'::
-
-        {% with "foo" as meta_keywords %}
-            {% meta_keywords %}
-        {% endwith %}
-
-    You can also provide the meta keywords as an argument to this tag::
-
-        {% meta_keywords "foo" %}
-
-    """
-    if keywords is None:
-        keywords = context.get("meta_keywords")
-    if keywords is None:
-        request = context["request"]
-        page = request.pages.current
-        if page:
-            keywords = page.meta_keywords
-    return escape(keywords or "")
-
-
 @register.simple_tag(takes_context=True)
 def meta_robots(context, index=None, follow=None, archive=None):
     """
@@ -180,6 +162,194 @@ def meta_robots(context, index=None, follow=None, archive=None):
     return escape(robots)
 
 
+def absolute_domain_url(context):
+    request = context['request']
+
+    https = 's' if request.is_secure() else ''
+
+    return 'http{}://{}'.format(
+        https,
+        settings.SITE_DOMAIN
+    )
+
+
+@register.simple_tag(takes_context=True)
+def canonical_url(context):
+    request = context['request']
+
+    url = '{}{}'.format(
+        absolute_domain_url(context),
+        request.path
+    )
+
+    return escape(url)
+
+
+@register.simple_tag(takes_context=True)
+def og_title(context, title=None):
+    if title is None:
+        title = context.get('og_title')
+
+    if title is None or title == '':
+        request = context['request']
+        page = request.pages.current
+
+        if page:
+            title = page.og_title
+
+        if not title:
+            title = context.get('title') or (page and page.title) or (page and page.browser_title)
+
+    return escape(title or '')
+
+
+@register.simple_tag(takes_context=True)
+def og_description(context, description=None):
+    if description is None:
+        description = context.get('og_description')
+
+    if description is None:
+        request = context['request']
+        page = request.pages.current
+
+        if page:
+            description = page.og_description
+
+    return escape(description or '')
+
+
+@register.simple_tag(takes_context=True)
+def og_image(context, image=None):
+    image_obj = None
+
+    if image is None:
+        image_obj = context.get('og_image')
+
+    if image_obj is None:
+        request = context['request']
+        page = request.pages.current
+
+        if page:
+            image_obj = page.og_image
+
+    if image_obj:
+        image = '{}{}'.format(
+            absolute_domain_url(context),
+            image_obj.get_absolute_url()
+        )
+
+    return escape(image or '')
+
+
+@register.simple_tag(takes_context=True)
+def twitter_card(context, card=None):
+    choices = dict(SearchMetaBase._meta.get_field('twitter_card').choices)
+
+    # Load from context if exists
+    if not card:
+        card = context.get('twitter_card')
+
+    # If we are still None, look at page content
+    if not card:
+
+        # Get current page from request
+        request = context['request']
+        current_page = request.pages.current
+        homepage = request.pages.homepage
+
+        # Use either the current page twitter card, or the homepage twitter card
+        card = current_page.twitter_card or homepage.twitter_card
+
+    if card or card == 0:
+        card = str(choices[card]).lower()
+
+    return escape(card or '')
+
+
+@register.simple_tag(takes_context=True)
+def twitter_title(context, title=None):
+
+    # Load from context if exists
+    if not title:
+        title = context.get('twitter_title')
+
+    # If we are still None, look at page content
+    if not title:
+
+        # Get current page from request
+        request = context['request']
+        current_page = request.pages.current
+        homepage = request.pages.homepage
+
+        # Use either the current page twitter title, or the homepage twitter title
+        title = current_page.twitter_title or homepage.twitter_title
+
+        # If everything fails, fallback to OG tag title
+        if not title:
+            title = og_title(context)
+
+    # Return title, or an empty string if nothing is working
+    return escape(title or '')
+
+
+@register.simple_tag(takes_context=True)
+def twitter_description(context, description=None):
+    # Load from context if exists
+    if not description:
+        description = context.get('twitter_description')
+
+    # If we are still None, look at page content
+    if not description:
+
+        # Get current page from request
+        request = context['request']
+        current_page = request.pages.current
+        homepage = request.pages.homepage
+
+        # Use either the current page twitter description, or the homepage twitter description
+        description = current_page.twitter_description or homepage.twitter_description
+
+        # If everything fails, fallback to OG tag title
+        if not description:
+            description = og_description(context)
+
+    # Return description, or an empty string if nothing is working
+    return escape(description or '')
+
+
+@register.simple_tag(takes_context=True)
+def twitter_image(context, image=None):
+    # Load from context if exists
+    if not image:
+        image = context.get('twitter_image')
+
+    # Get current page from request
+    request = context['request']
+
+    # If we are still None, look at page content
+    if not image:
+
+        current_page = request.pages.current
+        homepage = request.pages.homepage
+
+        # Use either the current page twitter image, or the homepage twitter image
+        image = current_page.twitter_image or homepage.twitter_image
+
+        # If everything fails, fallback to OG tag title
+        if not image:
+            image = og_image(context)
+
+    # If its a file object, load the URL manually
+    if type(image).__name__ == 'File' and hasattr(request, "META"):
+        image = "{}{}".format(
+            absolute_domain_url(context),
+            image.get_absolute_url()
+        )
+
+    # Return image, or an empty string if nothing is working
+    return escape(image or '')
+
+
 @register.inclusion_tag("pages/title.html", takes_context=True)
 def title(context, browser_title=None):
     """
@@ -266,3 +436,12 @@ def header(context, page_header=None):
     return {
         "header": page_header,
     }
+
+
+@register.simple_tag(takes_context=True)
+def country_code(context):
+    if hasattr(context.request, 'country') and context.request.country:
+        return '/{}'.format(
+            context.request.country.code.lower()
+        )
+    return ''
