@@ -1,4 +1,5 @@
 from copy import deepcopy
+from django.conf import settings
 from django.contrib import admin
 from django.contrib.admin.sites import AdminSite
 from django.contrib.admin.widgets import FilteredSelectMultiple, RelatedFieldWidgetWrapper
@@ -17,7 +18,6 @@ from ..models import get_registered_content, ContentBase, Page, CountryGroup, \
 from .... import externals
 
 import json
-import mock
 import os
 import sys
 
@@ -90,7 +90,7 @@ class TestPageAdmin(TestCase):
 
             self.homepage = Page.objects.create(
                 title="Homepage",
-                url_title='homepage',
+                slug='homepage',
                 content_type=content_type,
             )
 
@@ -224,7 +224,7 @@ class TestPageAdmin(TestCase):
 
             self.content_page = Page.objects.create(
                 title="Content page",
-                url_title='content_page',
+                slug='content_page',
                 parent=self.homepage,
                 content_type=content_type,
             )
@@ -233,44 +233,66 @@ class TestPageAdmin(TestCase):
                 page=self.content_page,
             )
 
-        pagecontent_fields = (
+        pagecontent_fields = [
             (None, {
-                'fields': ('title', 'url_title', 'parent')
+                'fields': ('title', 'slug', 'parent')
+            }),
+            ("Security", {
+                "fields": ("requires_authentication",),
             }),
             ('Publication', {
                 'fields': ('publication_date', 'expiry_date', 'is_online'),
                 'classes': ('collapse',)
             }),
             ('Navigation', {
-                'fields': ('short_title', 'in_navigation'),
+                'fields': ('short_title', 'in_navigation', "hide_from_anonymous",),
                 'classes': ('collapse',)
             }),
             ('Search engine optimization', {
-                'fields': ('browser_title', 'meta_keywords', 'meta_description', 'sitemap_priority', 'sitemap_changefreq', 'robots_index', 'robots_follow', 'robots_archive'),
+                'fields': ('browser_title', 'meta_description', 'sitemap_priority', 'sitemap_changefreq', 'robots_index', 'robots_follow', 'robots_archive'),
                 'classes': ('collapse',)
+            }),
+            ("Open graph", {
+                "fields": ("og_title", "og_description", "og_image"),
+                "classes": ("collapse",)
+            }),
+            ("Open graph twitter", {
+                "fields": ("twitter_card", "twitter_title", "twitter_description", "twitter_image"),
+                "classes": ("collapse",)
             })
-        )
+        ]
 
-        pagecontentwithfields_fields = (
+        pagecontentwithfields_fields = [
             (None, {
-                'fields': ('title', 'url_title', 'parent')
+                'fields': ('title', 'slug', 'parent')
             }),
             ('Page content', {
                 'fields': ['description', 'inline_model']
             }),
+            ("Security", {
+                "fields": ("requires_authentication",),
+            }),
             ('Publication', {
                 'fields': ('publication_date', 'expiry_date', 'is_online'),
                 'classes': ('collapse',)
             }),
             ('Navigation', {
-                'fields': ('short_title', 'in_navigation'),
+                'fields': ('short_title', 'in_navigation', "hide_from_anonymous",),
                 'classes': ('collapse',)
             }),
             ('Search engine optimization', {
-                'fields': ('browser_title', 'meta_keywords', 'meta_description', 'sitemap_priority', 'sitemap_changefreq', 'robots_index', 'robots_follow', 'robots_archive'),
+                'fields': ('browser_title', 'meta_description', 'sitemap_priority', 'sitemap_changefreq', 'robots_index', 'robots_follow', 'robots_archive'),
                 'classes': ('collapse',)
+            }),
+            ("Open graph", {
+                "fields": ("og_title", "og_description", "og_image"),
+                "classes": ("collapse",)
+            }),
+            ("Open graph twitter", {
+                "fields": ("twitter_card", "twitter_title", "twitter_description", "twitter_image"),
+                "classes": ("collapse",)
             })
-        )
+        ]
 
         self.assertEqual(self.page_admin.get_fieldsets(request), pagecontent_fields)
         self.assertEqual(self.page_admin.get_fieldsets(request2), pagecontentwithfields_fields)
@@ -284,7 +306,7 @@ class TestPageAdmin(TestCase):
 
             self.content_page = Page.objects.create(
                 title="Content page",
-                url_title='content_page',
+                slug='content_page',
                 parent=self.homepage,
                 content_type=content_type,
             )
@@ -295,7 +317,7 @@ class TestPageAdmin(TestCase):
 
         # The `children` attribute is cached as long as we use the original
         # reference, so get the Page again.
-        self.homepage = Page.objects.get(url_title='homepage')
+        self.homepage = Page.objects.get(slug='homepage')
         self.assertListEqual(self.page_admin.get_all_children(self.homepage), [self.content_page])
 
     def test_pageadmin_get_breadcrumbs(self):
@@ -308,11 +330,14 @@ class TestPageAdmin(TestCase):
 
         form = self.page_admin.get_form(request)
 
-        keys = ['title', 'url_title', 'parent', 'publication_date',
-                'expiry_date', 'is_online', 'short_title', 'in_navigation',
-                'browser_title', 'meta_keywords', 'meta_description',
-                'sitemap_priority', 'sitemap_changefreq', 'robots_index',
-                'robots_follow', 'robots_archive']
+        keys = ['title', 'slug', 'parent', 'requires_authentication',
+                'publication_date', 'expiry_date', 'is_online', 'short_title',
+                'in_navigation', 'hide_from_anonymous', 'browser_title',
+                'meta_description', 'sitemap_priority', 'sitemap_changefreq',
+                'robots_index', 'robots_follow', 'robots_archive', 'og_title',
+                'og_description', 'og_image', 'twitter_card', 'twitter_title',
+                'twitter_description', 'twitter_image']
+
         self.assertListEqual(list(form.base_fields.keys()), keys)
 
         request = self._build_request()
@@ -323,7 +348,7 @@ class TestPageAdmin(TestCase):
 
             self.content_page = Page.objects.create(
                 title="Content page",
-                url_title='content_page',
+                slug='content_page',
                 parent=self.homepage,
                 content_type=content_type,
             )
@@ -334,11 +359,14 @@ class TestPageAdmin(TestCase):
 
         form = self.page_admin.get_form(request, obj=self.content_page)
 
-        keys = ['title', 'url_title', 'parent', 'description', 'inline_model',
-                'publication_date', 'expiry_date', 'is_online', 'short_title',
-                'in_navigation', 'browser_title', 'meta_keywords',
-                'meta_description', 'sitemap_priority', 'sitemap_changefreq',
-                'robots_index', 'robots_follow', 'robots_archive']
+        keys = ['title', 'slug', 'parent', 'description', 'inline_model',
+                'requires_authentication', 'publication_date', 'expiry_date',
+                'is_online', 'short_title', 'in_navigation',
+                'hide_from_anonymous',  'browser_title', 'meta_description',
+                'sitemap_priority', 'sitemap_changefreq', 'robots_index',
+                'robots_follow', 'robots_archive', 'og_title', 'og_description',
+                'og_image', 'twitter_card', 'twitter_title',
+                'twitter_description', 'twitter_image']
         self.assertListEqual(list(form.base_fields.keys()), keys)
 
         self.assertIsInstance(form.base_fields['inline_model'].widget, RelatedFieldWidgetWrapper)
@@ -359,10 +387,14 @@ class TestPageAdmin(TestCase):
         form = self.page_admin.get_form(request, obj=self.content_page)
 
         keys = ['title', 'description', 'inline_model',
-                'publication_date', 'expiry_date', 'is_online', 'short_title',
-                'in_navigation', 'browser_title', 'meta_keywords',
-                'meta_description', 'sitemap_priority', 'sitemap_changefreq',
-                'robots_index', 'robots_follow', 'robots_archive']
+                'requires_authentication', 'publication_date', 'expiry_date',
+                'is_online', 'short_title', 'in_navigation',
+                'hide_from_anonymous', 'browser_title', 'meta_description',
+                'sitemap_priority', 'sitemap_changefreq', 'robots_index',
+                'robots_follow', 'robots_archive', 'og_title', 'og_description',
+                'og_image', 'twitter_card', 'twitter_title',
+                'twitter_description', 'twitter_image']
+
         self.assertListEqual(list(form.base_fields.keys()), keys)
 
         self.content_page.is_content_object = False
@@ -394,7 +426,7 @@ class TestPageAdmin(TestCase):
 
         form = self.page_admin.get_form(request)(data={
             'title': 'Homepage',
-            'url_title': 'homepage',
+            'slug': 'homepage',
             'description': 'Foo'
         })
         form.is_valid()
@@ -490,6 +522,7 @@ class TestPageAdmin(TestCase):
         response = self.page_admin.change_view(request, str(self.homepage.pk))
         self.assertEqual(response.status_code, 200)
         self.assertEqual(response.context_data['title'], 'Change page')
+        self.assertFalse(response.context_data['display_language_options'])
 
         self.assertListEqual(list(response.context_data['language_pages']), [self.homepage, self.homepage_alt])
 
@@ -502,6 +535,16 @@ class TestPageAdmin(TestCase):
 
         response = self.page_admin.change_view(request, str(self.homepage.pk))
 
+        NEW_MIDDLEWARE_CLASSES = [
+            'cms.middleware.LocalisationMiddleware',
+        ] + settings.MIDDLEWARE_CLASSES
+
+        with self.settings(MIDDLEWARE_CLASSES=NEW_MIDDLEWARE_CLASSES):
+            request = self._build_request()
+            response = self.page_admin.change_view(request, str(self.homepage.pk))
+            self.assertEqual(response.status_code, 200)
+            self.assertTrue(response.context_data['display_language_options'])
+
     def test_pageadmin_revision_view(self):
         request = self._build_request()
 
@@ -593,7 +636,7 @@ class TestPageAdmin(TestCase):
 
             self.content_page = Page.objects.create(
                 title="Content page",
-                url_title='content_page',
+                slug='content_page',
                 parent=self.homepage,
                 content_type=content_type,
             )
@@ -602,7 +645,7 @@ class TestPageAdmin(TestCase):
                 page=self.content_page,
             )
 
-        request.pages.homepage = Page.objects.get(url_title='homepage')
+        request.pages.homepage = Page.objects.get(slug='homepage')
         response = self.page_admin.sitemap_json_view(request)
         sitemap = '{"createHomepageUrl": "/admin/pages/page/add/?from=sitemap", "addUrl": "/admin/pages/page/add/?from=sitemap&parent=__id__", "canAdd": true, "changeUrl": "/admin/pages/page/__id__/?from=sitemap", "entries": [{"isOnline": true, "canDelete": true, "title": "Homepage", "canChange": true, "id": ' + str(self.homepage.pk) + ', "children": [{"isOnline": true, "canDelete": true, "title": "Content page", "canChange": true, "id": ' + str(self.content_page.pk) + ', "children": []}]}], "deleteUrl": "/admin/pages/page/__id__/delete/?from=sitemap", "moveUrl": "/admin/pages/page/move-page/"}'
         self.assertDictEqual(json.loads(response.content.decode()), json.loads(sitemap))
@@ -645,7 +688,7 @@ class TestPageAdmin(TestCase):
 
             content_page_1 = Page.objects.create(
                 title="Foo",
-                url_title='foo',
+                slug='foo',
                 parent=self.homepage,
                 content_type=content_type,
             )
@@ -654,9 +697,22 @@ class TestPageAdmin(TestCase):
                 page=content_page_1,
             )
 
+            # Create an alternative page.
+            alternative_page = Page.objects.create(
+                is_content_object=True,
+                owner=content_page_1,
+                left=content_page_1.left,
+                right=content_page_1.right,
+                content_type=content_type,
+            )
+
+            PageContent.objects.create(
+                page=alternative_page,
+            )
+
             content_page_2 = Page.objects.create(
                 title="Bar",
-                url_title='bar',
+                slug='bar',
                 parent=self.homepage,
                 content_type=content_type,
             )
@@ -665,10 +721,39 @@ class TestPageAdmin(TestCase):
                 page=content_page_2,
             )
 
+        self.homepage = Page.objects.get(pk=self.homepage.pk)
+        content_page_1 = Page.objects.get(pk=content_page_1.pk)
+        alternative_page = Page.objects.get(pk=alternative_page.pk)
+        content_page_2 = Page.objects.get(pk=content_page_2.pk)
+
+        self.assertEqual(self.homepage.left, 1)
+        self.assertEqual(self.homepage.right, 6)
+        self.assertEqual(content_page_1.left, 2)
+        self.assertEqual(content_page_1.right, 3)
+        self.assertEqual(alternative_page.left, 2)
+        self.assertEqual(alternative_page.right, 3)
+        self.assertEqual(content_page_2.left, 4)
+        self.assertEqual(content_page_2.right, 5)
+
+        # Move the page
         request.POST['page'] = content_page_1.pk
         request.POST['direction'] = 'down'
         response = self.page_admin.move_page_view(request)
 
+        self.homepage = Page.objects.get(pk=self.homepage.pk)
+        content_page_1 = Page.objects.get(pk=content_page_1.pk)
+        alternative_page = Page.objects.get(pk=alternative_page.pk)
+        content_page_2 = Page.objects.get(pk=content_page_2.pk)
+
+        self.assertEqual(self.homepage.left, 1)
+        self.assertEqual(self.homepage.right, 6)
+        self.assertEqual(content_page_1.left, 4)
+        self.assertEqual(content_page_1.right, 5)
+        self.assertEqual(alternative_page.left, 4)
+        self.assertEqual(alternative_page.right, 5)
+        self.assertEqual(content_page_2.left, 2)
+        self.assertEqual(content_page_2.right, 3)
+
         if six.PY2:
             self.assertEqual(response.content, "Page #" + six.text_type(content_page_1.pk) + " was moved down.")
         else:
@@ -680,7 +765,25 @@ class TestPageAdmin(TestCase):
         self.assertEqual(response.status_code, 403)
 
     def test_pageadmin_duplicate_for_country_group(self):
+        # Test without country groups first.
+        factory = RequestFactory()
+        request = factory.get('/?preview=a')
 
+        # Allow the messages framework to work.
+        setattr(request, 'session', 'session')
+        messages = FallbackStorage(request)
+        setattr(request, '_messages', messages)
+
+        response = self.page_admin.duplicate_for_country_group(request, page=self.homepage.pk)
+        self.assertEqual(response.status_code, 302)
+        self.assertEqual(response['Location'], '/admin/pages/page/' + str(self.homepage.pk))
+        self.assertEqual(len(request._messages._queued_messages), 1)
+        self.assertEqual(
+            request._messages._queued_messages[0].message,
+            "You need to add at least one country group first before you can add a copy of this page"
+        )
+
+        # Create country groups.
         self.country_group = CountryGroup.objects.create(
             name="United Kingdom"
         )
@@ -702,3 +805,33 @@ class TestPageAdmin(TestCase):
         )
         response = self.page_admin.duplicate_for_country_group(request, page=self.homepage.pk)
         self.assertEquals(Page.objects.filter(owner=self.homepage, is_content_object=True).count(), 1)
+
+        with externals.watson.context_manager("update_index")():
+
+            content_type_2 = ContentType.objects.get_for_model(
+                PageContentWithFields)
+
+            inline_page = Page.objects.create(
+                parent=self.homepage,
+                title="Inline page",
+                content_type=content_type_2,
+            )
+
+            PageContentWithFields.objects.create(
+                page=inline_page,
+            )
+
+            inline_model = InlineModel.objects.create(
+                page=inline_page,
+            )
+
+            request = self._build_request(method='POST')
+            request.POST = dict(
+                country_group=self.country_group.pk
+            )
+            response = self.page_admin.duplicate_for_country_group(request, page=inline_page.pk)
+            self.assertEquals(Page.objects.filter(owner=inline_page, is_content_object=True).count(), 1)
+
+            inline_page_clone = Page.objects.get(owner=inline_page, is_content_object=True)
+
+            self.assertEquals(inline_page_clone.inlinemodel_set.count(), 1)
