@@ -1,10 +1,9 @@
 """Tests for the pages app."""
 
 from django.db import models
-from django.test import TestCase, RequestFactory
+from django.test import TestCase
 from django.core.management import call_command
 from django.contrib.contenttypes.models import ContentType
-from ..admin import PageAdmin
 
 from ..models import filter_indexable_pages, ContentBase, Page, PageSearchAdapter, PageSitemap
 from .... import externals
@@ -39,7 +38,7 @@ class TestPage(TestCase):
 
             self.homepage = Page.objects.create(
                 title="Homepage",
-                url_title='homepage',
+                slug='homepage',
                 content_type=content_type,
             )
 
@@ -101,7 +100,7 @@ class TestPage(TestCase):
 
     def test_page_reverse(self):
         url = self.homepage.reverse('detail', kwargs={
-            'url_title': self.homepage.url_title
+            'slug': self.homepage.slug
         })
 
         self.assertEqual(url, '/homepage/')
@@ -151,6 +150,33 @@ class TestPage(TestCase):
 
             self.assertEqual(len(externals.watson.search("Homepage", models=(Page,))), 0)
 
+    def test_page_get_absolute_url(self):
+        with externals.watson.context_manager("update_index")():
+            Page.objects.all().delete()
+
+            content_type = ContentType.objects.get_for_model(TestPageContent)
+
+            new_page = Page(
+                content_type=content_type,
+                parent=None,
+                left=None,
+                right=None,
+            )
+            self.assertIsNone(new_page.cached_url)
+            new_page.save()
+            self.assertEqual(new_page.cached_url, '/')
+
+            TestPageContent.objects.create(
+                page=new_page,
+            )
+
+        self.assertEqual(new_page.get_absolute_url(), '/')
+        self.assertEqual(new_page.get_absolute_url(True), '/')
+
+        new_page = Page.objects.get(pk=new_page.pk)
+        self.assertEqual(new_page.cached_url, '/')
+        self.assertEqual(new_page.get_absolute_url(), '/')
+
 
 class TestSectionPage(TestCase):
 
@@ -160,7 +186,7 @@ class TestSectionPage(TestCase):
 
             self.homepage = Page.objects.create(
                 title="Homepage",
-                url_title='homepage',
+                slug='homepage',
                 content_type=content_type,
             )
 
@@ -172,7 +198,7 @@ class TestSectionPage(TestCase):
         search_adapter = PageSearchAdapter(Page)
 
         content = search_adapter.get_content(self.homepage)
-        self.assertEqual(content, "   homepage Homepage  / ")
+        self.assertEqual(content, "      homepage Homepage  / ")
 
 
 class TestPageComplex(TestCase):
@@ -241,11 +267,11 @@ class TestPageComplex(TestCase):
         self.pages = {}
 
         def _add_page(page, parent=None):
-            url_title = page['title'].replace(' ', '_').replace('-', '_')
+            slug = page['title'].replace(' ', '_').replace('-', '_')
 
             page_obj = Page.objects.create(
                 title=page['title'],
-                url_title=url_title,
+                slug=slug,
                 content_type=content_type,
                 parent=parent,
             )
@@ -254,7 +280,7 @@ class TestPageComplex(TestCase):
                 page=page_obj,
             )
 
-            self.page_ids[url_title] = page_obj.pk
+            self.page_ids[slug] = page_obj.pk
 
             if page.get('children', None):
                 for child in page['children']:
