@@ -6,8 +6,7 @@ from django.views.decorators.csrf import csrf_protect
 from cms.apps.pages import views
 
 
-urlpatterns = patterns("cms.apps.pages.views",
-
+urlpatterns = patterns(
+    "cms.apps.pages.views",
     url(r"^$", csrf_protect(views.ContentIndexView.as_view()), name="index")
-    
-)
\ No newline at end of file
+)
