@@ -266,6 +266,11 @@ def main():
                 "user": args.project_name,
                 "password": ""
             }
+        },
+        "opbeat": {
+            "organization_id": "dde034beb33d4b77bb9937c39f0c158f",
+            "app_id": "",
+            "secret_token": ""
         }
     }
 
@@ -275,14 +280,13 @@ def main():
     # Run `npm` commands.
     if not getattr(args, 'skip_frontend'):
         with open(os.devnull, 'w') as f:
-            Output().info("Installing bower and gulp")
-            subprocess.call(['npm', 'install', '-g', 'bower', 'gulp'], stdout=f, stderr=subprocess.STDOUT)
+            Output().info("Installing bower, babel and gulp")
+            subprocess.call(['npm', 'install', '-g', 'bower', 'gulp', 'babel'], stdout=f, stderr=subprocess.STDOUT)
 
             Output().info("Installing npm dependancies")
             subprocess.call(['npm', 'install'], stdout=f, stderr=subprocess.STDOUT)
 
             Output().info("Running gulp")
-            subprocess.call(['gulp', 'initialise'], stdout=f, stderr=subprocess.STDOUT)
             subprocess.call(['gulp', 'styles'], stdout=f, stderr=subprocess.STDOUT)
 
     # Give some help to the user.
