@@ -47,14 +47,14 @@ DATABASES = {
         "ENGINE": "django.db.backends.postgresql_psycopg2",
         "HOST": "localhost",
         "NAME": "{{ project_name }}",
-        "USER": "{{ user }}",
+        "USER": os.getlogin(),
         "PASSWORD": "",
     },
 }
 
 # Mailtrip SMTP
 EMAIL_HOST = 'mailtrap.io'
-EMAIL_HOST_USER = ''
-EMAIL_HOST_PASSWORD = ''
+EMAIL_HOST_USER = '178288370161874a6'
+EMAIL_HOST_PASSWORD = '5033a6d5bca3f0'
 EMAIL_PORT = '2525'
 EMAIL_USE_TLS = True
